/**
  *  \file game/pref.cc
  *  \brief User Preferences
  *
  *  This file contains the user preferences (in contrast to
  *  game/config.cc, which contains the game configuration). This
  *  must be in game/, because some game code depends on it.
  *
  *  (c) 2001-2009 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/pref.h"

static ValueIntParser parse_int;
static ValueBoolParser parse_bool;

GUserPreferences::GUserPreferences()
    : CollapseOldMessages(*this, "Messages.CollapseOld", parse_bool),
      InstantBattleResult(*this, "VCR.InstantResult", parse_int),

      Sound16Bits(*this, "Sound.16Bits", parse_bool),
      SoundEnabled(*this, "Sound.Enabled", parse_bool),
      SoundFrequency(*this, "Sound.Frequency", parse_int),
      SoundHeadphone(*this, "Sound.Headphone", parse_bool),
      SoundReverse(*this, "Sound.Reverse", parse_bool),
      SoundStereo(*this, "Sound.Stereo", parse_bool),
      ChartAnimThreshold(*this, "Chart.AnimThreshold", parse_int)
{
    assignDefaults();
}

void
GUserPreferences::assignDefaults()
{
    CollapseOldMessages.set(false);
    InstantBattleResult.set(true);

    Sound16Bits.set(true);
    SoundEnabled.set(true);
    SoundFrequency.set(22050);
    SoundHeadphone.set(false);
    SoundReverse.set(false);
    SoundStereo.set(true);

    ChartAnimThreshold.set(11);
}

extern GUserPreferences&
getUserPreferences()
{
    static GUserPreferences user_pref;
    return user_pref;
}
