/**
  *  \file gfx/gfxtypes.h
  *  \brief Types referring to the Underlying Graphics Library
  *
  *  The types and constants defined here-in are used in the
  *  interface, to allow a semi-portable notation of various code. The
  *  intention is to simplify a (future) port to different graphics
  *  libraries, like Xlib, Allegro, etc.
  *
  *  (c) 2001-2009 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GFX_GFXTYPES_H
#define PCC_V2_GFX_GFXTYPES_H

#include <SDL_video.h>
#include "cpluslib/types.h"

/** Transparent color. When a background color is requested, specify
    this value to draw transparent. This value has been chosen to be
    a very unlikely if not impossible return value of SDL_MapRGB(). */
static const uint32 GFX_TRANSPARENT       = 0xFFFFFFFEU;
static const uint8  GFX_ALPHA_OPAQUE      = SDL_ALPHA_OPAQUE;
static const uint8  GFX_ALPHA_TRANSPARENT = SDL_ALPHA_TRANSPARENT;

/** Type for alpha channel. In theory, any type does (and int should
    be the fastest of them). Right now, only uint8 seems to work, though. */
typedef uint8 alpha_type;

/** Surface type. Every GfxSurface has an underlying system surface
    (such as a screen, memory object, etc.) */
typedef SDL_Surface*     GfxSystemSurface;

/** Pixel format. Every surface has an associated pixel format. These
    are used as handles to create new surfaces. */
typedef SDL_PixelFormat* GfxSystemPixelFormat;

#endif
