#include <iostream>
#include "game/cargo.h"
#include "cpluslib/format.h"
#include "util/console.h"
#include "game/cargotype.h"

typedef GCargoType CargoType;

class TestObject : public GCargoContainer {
    GCargoArbiter cargo;
    int content[el_COUNT];
 public:
    TestObject();
    ~TestObject();

    int32  getCargoOnObject(CargoType type);
    void   changeCargoOnObject(CargoType type, int32 amount);
    void   changeReservedCargo(CargoType type, int32 amount);
    bool     canHaveCargo(CargoType cargo_id);
    int32    getMaxCargo(CargoType cargo_id);
    string_t getName() const;
    void dump(GCargoCostTransaction& act);
};

TestObject::TestObject()
    : cargo()
{
    cargo.incUseCount();
    for (int i = 0; i < el_COUNT; ++i)
        content[i] = 1000;
}

TestObject::~TestObject()
{
    cargo.decUseCount();
}

int32
TestObject::getCargoOnObject(CargoType type)
{
    return content[type] - cargo.getReservedCargo(type);
}

void
TestObject::changeCargoOnObject(CargoType type, int32 amount)
{
    content[type] += amount;
    std::cout << "changed " << getCargoName(type)
              << " by " << amount << " to " << content[type] << "\n";
}

void
TestObject::changeReservedCargo(CargoType type, int32 amount)
{
    cargo.changeReservedCargo(type, amount);
    if (type < el_Torps) {
        std::cout << "changed reservation for " << getCargoName(type)
                  << " by " << amount << " to " << cargo.getReservedCargo(type) << "\n";
    } else {
        // we have not loaded the specification, hence getCargoName() would segfault
        std::cout << "changed reservation for torp " << (type-el_Torps+1)
                  << " by " << amount << " to " << cargo.getReservedCargo(type) << "\n";
    }
}

bool
TestObject::canHaveCargo(CargoType /*cargo_id*/)
{
    return true;
}

int32
TestObject::getMaxCargo(CargoType /*cargo_id*/)
{
    return 1000000;
}

string_t
TestObject::getName() const
{
    return string_t("Test Object");
}

void
TestObject::dump(GCargoCostTransaction& act)
{
    std::cout << "Type                  Have   Resvd    Cost   Remain Miss\n"
              << "--------------------  -----  -----    -----  -----  -----\n";
    for (int i = 0; i < el_Torps; ++i) {
        GCargoType t = GCargoType(i);
        if (t != el_Tritanium && t != el_Molybdenum && t != el_Duranium
            && t != el_Supplies && t != el_Money)
            continue;
        std::cout << (format("%-16s (%d): %5d  %5d    %5d  %5d  %5d\n")
                      << getCargoName(t)
                      << i
                      << content[t]
                      << cargo.getReservedCargo(t)
                      << act.getCost(t)
                      << act.getRemaining(t)
                      << act.getMissing(t));
    }
}

class TestTA : public GCargoCostTransaction {
 public:
    TestTA(TestObject& con);
};

TestTA::TestTA(TestObject& con)
    : GCargoCostTransaction(con)
{
    std::cout << "(q)uit (c)ommit (d)isplay (a)ddcost (s)ubcost\n";
    char c;
    int n, x;
    while (std::cin.get(c)) {
        switch (c) {
         case 'q':
            doCancel();
            con.doCancel();
            return;
         case 'c':
            std::cout << "commit...\n";
            doCommit();
            con.doCommit();
            return;
         case 'd':
            con.dump(*this);
            if (isValidCost())
                std::cout << "-- VALID --\n";
            else
                std::cout << "-- INVALID --\n";
            break;
         case 'a':
            std::cin >> n >> x;
            changeCost(GCargoType(n), x);
            break;
         case 's':
            std::cin >> n >> x;
            changeCost(GCargoType(n), -x);
            break;
        }
    }
    doCancel();
    con.doCancel();    
}

int main()
{
    enableStdioConsole();
    TestObject t;
    TestTA ta(t);
}
