/**
  *  \file u/t_io_textfile.cc
  *
  *  (c) 2001-2009 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "io/textfile.h"

#include "u/t_io.h"
#include "io/memstream.h"

void
IoTextfileTestSuite::testGetChar()
{
    MemoryStream ms("123\012abc");
    TextFile tf(ms);

    TS_ASSERT_EQUALS(tf.peekByte(), '1');
    TS_ASSERT_EQUALS(tf.getByte(),  '1');

    TS_ASSERT_EQUALS(tf.peekByte(), '2');
    TS_ASSERT_EQUALS(tf.getByte(),  '2');

    TS_ASSERT_EQUALS(tf.peekByte(), '3');
    TS_ASSERT_EQUALS(tf.getByte(),  '3');

    TS_ASSERT_EQUALS(tf.peekByte(), 10);
    TS_ASSERT_EQUALS(tf.getByte(),  10);

    TS_ASSERT_EQUALS(tf.peekByte(), 'a');
    TS_ASSERT_EQUALS(tf.getByte(),  'a');

    TS_ASSERT_EQUALS(tf.peekByte(), 'b');
    TS_ASSERT_EQUALS(tf.getByte(),  'b');

    TS_ASSERT_EQUALS(tf.peekByte(), 'c');
    TS_ASSERT_EQUALS(tf.getByte(),  'c');

    TS_ASSERT_EQUALS(tf.peekByte(), -1);
    TS_ASSERT_EQUALS(tf.getByte(),  -1);

    TS_ASSERT_EQUALS(tf.peekByte(), -1);
    TS_ASSERT_EQUALS(tf.getByte(),  -1);

    TS_ASSERT_EQUALS(tf.peekByte(), -1);
    TS_ASSERT_EQUALS(tf.getByte(),  -1);
}

void
IoTextfileTestSuite::doGetLineTest(const char* data, const char* name)
{
    MemoryStream ms(data);
    TextFile tf(ms);
    string_t line;
    TSM_ASSERT(name, tf.getLine(line));
    TSM_ASSERT_EQUALS(name, line, "abc");

    TSM_ASSERT(name, tf.getLine(line));
    TSM_ASSERT_EQUALS(name, line, "def");

    TSM_ASSERT(name, !tf.getLine(line));
    TSM_ASSERT_EQUALS(name, line, "");
}

void
IoTextfileTestSuite::testGetLine()
{
    doGetLineTest("abc\012def\012",         "Unix");
    doGetLineTest("abc\015\012def\015\012", "DOS");
    doGetLineTest("abc\015def\015",         "Mac");
    doGetLineTest("abc\012def",             "Unix unterminated");
    doGetLineTest("abc\015\012def",         "DOS unterminated");
    doGetLineTest("abc\015def",             "Mac unterminated");

    doGetLineTest("abc\012def\012\032",         "Unix C-z");
    doGetLineTest("abc\015\012def\015\012\032", "DOS C-z");
    doGetLineTest("abc\015def\015\032",         "Mac C-z");
    doGetLineTest("abc\012def\032",             "Unix unterminated C-z");
    doGetLineTest("abc\015\012def\032",         "DOS unterminated C-z");
    doGetLineTest("abc\015def\032",             "Mac unterminated C-z");
}
