/**
  *  \file ui/dlg-fileselect.h
  *
  *  (c) 2001-2009 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_DLG_FILESELECT_H
#define PCC_V2_UI_DLG_FILESELECT_H

#include <vector>
#include "ui/window.h"
#include "ui/listbox.h"
#include "io/dirs.h"
#include "io/glob.h"
#include "ui/widgets.h"


class UIFileList : public UIListbox {
    string_t wildcard;
    Ptr<Directory> directory;
    std::vector<Ptr<DirectoryEntry> > content;
    FileNamePattern pat;

    string_t result;
 public:
    UIFileList(int id, Ptr<Directory> directory, string_t wildcard, int lines);
    ~UIFileList();

    void update(Ptr<Directory> dir);
    void drawPart(GfxCanvas& can, int from, int to);

    string_t getCurrentSelection() const;
    bool handleInput(string_t input);

    const string_t& getResult() const
        { return result; }
};

class UIFileListWindow : public UIWindow {
    ObjectHolder h;
    UIFileList   list;
    UIInputLine  input;

    void onOK();
    void onCancel();
    void onMove();
 public:
    UIFileListWindow(string_t title, string_t wildcard);
    ~UIFileListWindow();

    string_t getSelectedFile() const;
};

#endif
