/**
  *  \file ui/panel.cc
  *  \brief Panel widget
  *
  *  (c) 2001-2009 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/panel.h"
#include "ui/skin.h"
#include "ui/uiglobal.h"
#include "gfx/palette.h"
#include "ui/layout.h"
#include "ui/util.h"

namespace {
    class UIPanelSkin : public UISkin {
     public:
        const UIColorSet& getColors() const;
        void outText(GfxCanvas& can,  int f, int x, int y, string_t text);
        void outTextF(GfxCanvas& can, int f, int x, int y, int lim, string_t text);
        void drawBackground(GfxCanvas& can, GfxRect r);
    };
    UIPanelSkin panel_skin_instance;
}

const UIColorSet&
UIPanelSkin::getColors() const
{
    return DARK_COLOR_SET;
}

void
UIPanelSkin::outText(GfxCanvas& can,  int f, int x, int y, string_t text)
{
    parm.font = fonts[f];
    parm.bgcolor = isSolid() ? standard_colors[COLOR_DARK] : GFX_TRANSPARENT;
    ::outText(can, parm, x, y, text);
}

void
UIPanelSkin::outTextF(GfxCanvas& can, int f, int x, int y, int lim, string_t text)
{
    parm.font = fonts[f];
    parm.bgcolor = isSolid() ? standard_colors[COLOR_DARK] : GFX_TRANSPARENT;
    ::outTextF(can, parm, x, y, lim, text);
}

void
UIPanelSkin::drawBackground(GfxCanvas& can, GfxRect r)
{
    drawSolidBar(can, r, standard_colors[COLOR_DARK]);
}

/******************************** UIPanel ********************************/

/** Constructor.
    \param space Pixels to reserve (and not to give to sub-layout) at borders */
UIPanel::UIPanel(int space)
    : UILayoutableWidget(UINullLayout::instance),
      space(space)
{
    setSkin(panel_skin_instance);
}

UIPanel::~UIPanel()
{ }

void
UIPanel::drawContent(GfxCanvas& can)
{
    GfxRect r = getExtent();
    drawFrameUp(can, r);
    r.grow(-1, -1);
    drawSolidBar(can, r, standard_colors[COLOR_DARK]);
    can.update(getExtent());
}

void
UIPanel::adjustSize(GfxRect& size, bool to_inner)
{
    if (to_inner)
        size.grow(-space, -space);
    else
        size.grow(space, space);
}
